@@ -30,8 +30,8 @@ def tree():
 
 
 @pytest.fixture
-def bst():
-    return tree()
+def bst(tree):
+    return tree
 
 
 def test_bst_add(bst):
